ET_Error

Enum ET_Error 

#[repr(u32)]
pub enum ET_Error {
Show 21 variants ET_Error_Ok = 0, ET_Error_Internal = 1, ET_Error_InvalidState = 2, ET_Error_EndOfMethod = 3, ET_Error_AlreadyLoaded = 4, ET_Error_NotSupported = 16, ET_Error_NotImplemented = 17, ET_Error_InvalidArgument = 18, ET_Error_InvalidType = 19, ET_Error_OperatorMissing = 20, ET_Error_RegistrationExceedingMaxKernels = 21, ET_Error_RegistrationAlreadyRegistered = 22, ET_Error_NotFound = 32, ET_Error_MemoryAllocationFailed = 33, ET_Error_AccessFailed = 34, ET_Error_InvalidProgram = 35, ET_Error_InvalidExternalData = 36, ET_Error_OutOfResources = 37, ET_Error_DelegateInvalidCompatibility = 48, ET_Error_DelegateMemoryAllocationFailed = 49, ET_Error_DelegateInvalidHandle = 50,
}
ExecuTorch ET_Error type.

Variants



ET_Error_Ok = 0

Status indicating a successful operation.



ET_Error_Internal = 1

An internal error occurred.



ET_Error_InvalidState = 2

Status indicating the executor is in an invalid state for a target operation



ET_Error_EndOfMethod = 3

Status indicating there are no more steps of execution to run



ET_Error_AlreadyLoaded = 4

Status indicating a resource has already been loaded.



ET_Error_NotSupported = 16

Operation is not supported in the current context.



ET_Error_NotImplemented = 17

Operation is not yet implemented.



ET_Error_InvalidArgument = 18

User provided an invalid argument.



ET_Error_InvalidType = 19

Object is an invalid type for the operation.



ET_Error_OperatorMissing = 20

Operator(s) missing in the operator registry.



ET_Error_RegistrationExceedingMaxKernels = 21

Registration error: Exceeding the maximum number of kernels.



ET_Error_RegistrationAlreadyRegistered = 22

Registration error: The kernel is already registered.



ET_Error_NotFound = 32

Requested resource could not be found.



ET_Error_MemoryAllocationFailed = 33

Could not allocate the requested memory.



ET_Error_AccessFailed = 34

Could not access a resource.



ET_Error_InvalidProgram = 35

ET_Error caused by the contents of a program.



ET_Error_InvalidExternalData = 36

ET_Error caused by the contents of external data.



ET_Error_OutOfResources = 37

Does not have enough resources to perform the requested operation.



ET_Error_DelegateInvalidCompatibility = 48

Init stage: Backend receives an incompatible delegate version.



ET_Error_DelegateMemoryAllocationFailed = 49

Init stage: Backend fails to allocate memory.



ET_Error_DelegateInvalidHandle = 50

Execute stage: The handle is invalid.