ET_MmapDataLoaderMlockConfig

Enum ET_MmapDataLoaderMlockConfig 

#[repr(u32)]
pub enum ET_MmapDataLoaderMlockConfig { ET_MmapDataLoaderMlockConfig_NoMlock = 0, ET_MmapDataLoaderMlockConfig_UseMlock = 1, ET_MmapDataLoaderMlockConfig_UseMlockIgnoreErrors = 2, ET_MmapDataLoaderMlockConfig_UseMadvise = 3, }
Describes how and whether to lock loaded pages with mlock().

Using mlock() typically loads all of the pages immediately, and will typically ensure that they are not swapped out. The actual behavior will depend on the host system.

Variants



ET_MmapDataLoaderMlockConfig_NoMlock = 0

Do not call mlock() on loaded pages.



ET_MmapDataLoaderMlockConfig_UseMlock = 1

Call mlock() on loaded pages, failing if it fails.



ET_MmapDataLoaderMlockConfig_UseMlockIgnoreErrors = 2

Call mlock() on loaded pages, ignoring errors if it fails.



ET_MmapDataLoaderMlockConfig_UseMadvise = 3

Use madvise(MADV_WILLNEED | MADV_SEQUENTIAL) instead of mlock. Tells the kernel to prefetch pages eagerly and optimize for sequential reads, without pinning them in RAM.