Error

Enum Error 

#[repr(u32)]
pub enum Error {
Show 20 variants Error_Ok = 0, Error_Internal = 1, Error_InvalidState = 2, Error_EndOfMethod = 3, Error_NotSupported = 16, Error_NotImplemented = 17, Error_InvalidArgument = 18, Error_InvalidType = 19, Error_OperatorMissing = 20, Error_RegistrationExceedingMaxKernels = 21, Error_RegistrationAlreadyRegistered = 22, Error_NotFound = 32, Error_MemoryAllocationFailed = 33, Error_AccessFailed = 34, Error_InvalidProgram = 35, Error_InvalidExternalData = 36, Error_OutOfResources = 37, Error_DelegateInvalidCompatibility = 48, Error_DelegateMemoryAllocationFailed = 49, Error_DelegateInvalidHandle = 50,
}
ExecuTorch Error type.

Variants



Error_Ok = 0

Status indicating a successful operation.



Error_Internal = 1

An internal error occurred.



Error_InvalidState = 2

Status indicating the executor is in an invalid state for a target operation



Error_EndOfMethod = 3

Status indicating there are no more steps of execution to run



Error_NotSupported = 16

Operation is not supported in the current context.



Error_NotImplemented = 17

Operation is not yet implemented.



Error_InvalidArgument = 18

User provided an invalid argument.



Error_InvalidType = 19

Object is an invalid type for the operation.



Error_OperatorMissing = 20

Operator(s) missing in the operator registry.



Error_RegistrationExceedingMaxKernels = 21

Registration error: Exceeding the maximum number of kernels.



Error_RegistrationAlreadyRegistered = 22

Registration error: The kernel is already registered.



Error_NotFound = 32

Requested resource could not be found.



Error_MemoryAllocationFailed = 33

Could not allocate the requested memory.



Error_AccessFailed = 34

Could not access a resource.



Error_InvalidProgram = 35

Error caused by the contents of a program.



Error_InvalidExternalData = 36

Error caused by the contents of external data.



Error_OutOfResources = 37

Does not have enough resources to perform the requested operation.



Error_DelegateInvalidCompatibility = 48

Init stage: Backend receives an incompatible delegate version.



Error_DelegateMemoryAllocationFailed = 49

Init stage: Backend fails to allocate memory.



Error_DelegateInvalidHandle = 50

Execute stage: The handle is invalid.