Module_load

Function Module_load 

pub unsafe fn Module_load(
    self_: Pin<&mut Module>,
    backend_options: *const ET_LoadBackendOptionsMap,
    verification: ET_ProgramVerification,
) -> ET_Error
Available on crate features module and std only.
Load the program if needed, optionally with per-delegate load-time options.

Arguments

  • backend_options: Per-delegate load-time options, or null. When non-null the Module deep-copies it into internal storage, so the caller may drop the map immediately after this returns.
  • verification: The type of verification to do before returning success.

Returns

An ET_Error to indicate success or failure of the loading process.

Safety

backend_options must be null or point to a valid ET_LoadBackendOptionsMap.