#[repr(u8)]pub enum ET_ProgramVerification {
ET_ProgramVerification_Minimal = 0,
ET_ProgramVerification_InternalConsistency = 1,
}Expand description
Types of validation that the ET_Program can do before parsing the data.
Variants
ET_ProgramVerification_Minimal = 0
Do minimal verification of the data, ensuring that the header appears correct.
Has minimal runtime overhead.
ET_ProgramVerification_InternalConsistency = 1
Do full verification of the data, ensuring that internal pointers are self-consistent and that the data has not been truncated or obviously corrupted. May not catch all types of corruption, but should guard against illegal memory operations during parsing.
Will have higher runtime overhead, scaling with the complexity of the proram data.